/***************************************************************************
                           flashcardswidget.h  -  description
                             -------------------
    begin                : Fri Feb 15 2002
    copyright            : (C) 2002 by Scott Wheeler
    email                : wheeler@kde.org
***************************************************************************/

/***************************************************************************
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
***************************************************************************/

#ifndef FLASHCARDSWIDGET_H
#define FLASHCARDSWIDGET_H

#include "quizwidget.h"

class KStatusBar;

class Card;

class FlashCardsWidget : public QuizWidget
{
public: 
  FlashCardsWidget(KStatusBar *statusBar, QWidget *parent, const char *name = 0);
  virtual ~FlashCardsWidget();

private:
  void setupLayout();
  virtual void showCard(const Card &card);
  
  QTabWidget *tabWidget;
  QLabel *frontLabel;
  QLabel *backLabel; 
};

#endif
